@@ -28,7 +28,7 @@ use Algorithm::Dependency ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.106';
+	$VERSION = '1.107';
 	@ISA     = 'Algorithm::Dependency';
 }
 
@@ -105,7 +105,7 @@ For general comments, contact the author.
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>, L<http://ali.as/>
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
@@ -113,7 +113,7 @@ L<Algorithm::Dependency>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003 - 2005 Adam Kennedy.
+Copyright 2003 - 2009 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
