@@ -57,7 +57,7 @@ use Algorithm::Dependency::Source ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.106';
+	$VERSION = '1.107';
 	@ISA     = 'Algorithm::Dependency::Source';
 }
 
@@ -142,7 +142,7 @@ For other comments, contact the author.
 
 =head1 AUTHOR
 
-Adam Kennedy, L<http://ali.as/>, cpan@ali.as
+Adam Kennedy <adamk@cpan.org>
 
 =head1 SEE ALSO
 
@@ -150,7 +150,7 @@ L<Algorithm::Dependency>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003 - 2005 Adam Kennedy.
+Copyright 2003 - 2009 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
