@@ -31,13 +31,15 @@ L<Algorithm::Dependency::Source> methods.
 
 =cut
 
+use 5.005;
 use strict;
-use base 'Algorithm::Dependency::Source';
+use Algorithm::Dependency::Source ();
 use Params::Util qw{_HASH _ARRAY0};
 
-use vars qw{$VERSION};
+use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.104';
+	$VERSION = '1.107';
+	@ISA     = 'Algorithm::Dependency::Source';
 }
 
 
@@ -109,7 +111,7 @@ For other comments, contact the author.
 
 =head1 AUTHOR
 
-Adam Kennedy, L<http://ali.as/>, cpan@ali.as
+Adam Kennedy <adamk@cpan.org>
 
 =head1 SEE ALSO
 
@@ -117,7 +119,7 @@ L<Algorithm::Dependency>, L<Algorithm::Dependency::Source>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003 - 2005 Adam Kennedy.
+Copyright 2003 - 2009 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
