@@ -63,6 +63,7 @@ the situation, which is probably more important.
 
 =cut
 
+use 5.005;
 use strict;
 use List::Util            ();
 use Algorithm::Dependency ();
@@ -70,7 +71,7 @@ use Params::Util qw{_INSTANCE _IDENTIFIER};
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.104';
+	$VERSION = '1.107';
 }
 
 
@@ -245,7 +246,7 @@ For general comments, contact the author.
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>, L<http://ali.as/>
+Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
@@ -253,7 +254,7 @@ L<Algorithm::Dependency>, L<Algorithm::Dependency::Source>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003 - 2005 Adam Kennedy.
+Copyright 2003 - 2009 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
